@@ -308,23 +308,33 @@ class VPTStateSpace:
                 cls.get_state_list_from_quanta(0, n_modes),
                 states,
                 [
-                    HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x", "x"),
-                    HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x", "x", "x")
+                    HarmonicOscillatorProductBasis(n_modes).selection_rules(*["x"]*i) for i in range(3, order+3)
                 ],
                 [
-                    # (),
-                    # (),
-                    # ()
-                    HarmonicOscillatorProductBasis(n_modes).selection_rules("x"),
-                    HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x"),
-                    HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x", "x")
+                    HarmonicOscillatorProductBasis(n_modes).selection_rules(*["x"]*i) for i in range(1, order+2)
                 ]
             )
         elif target == 'frequencies':
-            return {
-                (1, 1): ([],),
-                (2, 0): (None, [[]])
-            }
+            # return {
+            #     (1, 1): ([],),
+            #     (2, 0): (None, [[0]])
+            # }
+            return PerturbationTheoryStateSpaceFilter.from_property_rules(
+                cls.get_state_list_from_quanta(0, n_modes),
+                states,
+                [
+                    HarmonicOscillatorProductBasis(n_modes).selection_rules(*["x"] * i) for i in range(3, order + 3)
+                ],
+                None
+                # [
+                #     # (),
+                #     # (),
+                #     # ()
+                #     # HarmonicOscillatorProductBasis(n_modes).selection_rules("x"),
+                #     # HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x"),
+                #     # HarmonicOscillatorProductBasis(n_modes).selection_rules("x", "x", "x")
+                # ]
+            )
 
 class VPTHamiltonianOptions:
     """
@@ -560,7 +570,7 @@ class VPTRuntimeOptions:
         self.ham_opts = real_ham_opts
 
         solver_run_opts = dict(
-            operator_chunk_size=operator_chunk_size,
+            # operator_chunk_size=operator_chunk_size,
             memory_constrained=memory_constrained,
             verbose=verbose,
             checkpoint_keys=checkpoint_keys,
@@ -925,7 +935,11 @@ class VPTRunner:
         if target_property is None and order == 2:
             target_property = 'intensities'
         if target_property is not None and 'state_space_filters' not in opts:
-            par.ops['state_space_filters'] = states.filter_generator(target_property, order=order)
+            if 'expansion_order' in opts.keys():
+                expansion_order = opts['expansion_order']
+            else:
+                expansion_order = order
+            par.ops['state_space_filters'] = states.filter_generator(target_property, order=expansion_order)
 
             # print(par.ops['state_space_filters'])
 
@@ -1221,23 +1235,34 @@ class AnneInputHelpers:
             r_coords = [0, 1, 3]
             a_coords = [2, 4]
             t_coords = [5]
-            extra = np.arange(6, ncoords)
-            r_coords += extra[::4].tolist()
-            a_coords += extra[1::4].tolist()
-            t_coords += extra[2::4].tolist()
+            if nats > 4:
+                extra = np.arange(6, ncoords+1)
+                r_coords += extra[::4].tolist()
+                a_coords += extra[1::4].tolist()
+                t_coords += extra[2::4].tolist()
             return np.argsort(np.concatenate([r_coords, a_coords, t_coords]))
 
     @classmethod
-    def renormalize_modes(cls, freqs, modes, inv, sorting=None):
-        # modes = (modes * np.sqrt(freqs)[:, np.newaxis]).T
-        # inv = inv#.T / np.sqrt(freqs)[:, np.newaxis]
-        G = np.dot(modes, modes.T)
-        F = np.dot(np.dot(inv.T, np.diag(freqs ** 2)), inv)
+    def get_internal_FG(cls, freqs, modes, inv, sorting=None):
+        modes = modes.T * np.sqrt(freqs)[:, np.newaxis]
+        inv = inv.T / np.sqrt(freqs)[np.newaxis, :]
+        G = np.dot(modes.T, modes)
+        # print(np.dot(modes, modes.T))
+        # print(np.dot(modes.T, modes))
+        F = np.dot(np.dot(inv, np.diag(freqs ** 2)), inv.T)
         if sorting is not None:
             G = G[np.ix_(sorting, sorting)]
+            # print(G)
             # print(np.round(F*219465))
             F = F[np.ix_(sorting, sorting)]
+            # print(F)
+        return F, G
+
+    @classmethod
+    def renormalize_modes(cls, freqs, modes, inv, sorting=None):
+        F, G = cls.get_internal_FG(freqs, modes, inv, sorting=sorting)
         freq, modes = scipy.linalg.eigh(F, G, type=2)
+        modes = modes * np.sqrt(freqs)[np.newaxis, :]
         return np.sqrt(freq), modes, np.linalg.inv(modes)
 
     @classmethod
@@ -1261,6 +1286,8 @@ class AnneInputHelpers:
     @classmethod
     def reexpress_normal_modes(cls, base_modes, old_field, sorting=None):
         freq, matrix, inv = cls.renormalize_modes(*base_modes, sorting=sorting)
+        # print(freq, matrix, inv)
+        # freq, matrix, inv = cls.renormalize_modes(*base_modes, sorting=sorting)
         potential_terms = cls.rerotate_force_field(
             base_modes[1],
             matrix.T,#/np.sqrt(freq)[np.newaxis, :],  # we divide by the sqrt of the frequencies to get the units to work
@@ -1274,6 +1301,9 @@ class AnneInputHelpers:
         )[0]
         return (freq, matrix, inv), potential_terms
 
+    # @classmethod
+    # def rephase_normal_modes(cls, ...):
+
     convert = UnitsData.convert
     @staticmethod
     def mass(atom):
@@ -1285,12 +1315,13 @@ class AnneInputHelpers:
                      states=2,
                      calculate_intensities=False,
                      return_analyzer=False,
+                     return_runner=False,
                      modes_file='nm_int.dat',
                      atoms_file='atom.dat',
                      coords_file='cart_ref.dat',
                      zmat_file='z_mat.dat',
                      potential_files=('cub.dat', 'quart.dat'),
-                     energy_units="Wavenumbers",
+                     energy_units=None,
                      **opts
                      ):
         from .Analyzer import VPTAnalyzer
@@ -1300,14 +1331,29 @@ class AnneInputHelpers:
             if base_dir is not None:
                 os.chdir(base_dir)
 
-            conv = cls.convert(energy_units, "Hartrees")
             base_freqs, base_mat, base_inv = cls.parse_modes(modes_file)
+            if energy_units is None:
+                if np.max(base_freqs) > 1:
+                    conv = cls.convert("Wavenumbers", "Hartrees")
+                else:
+                    conv = 1
+            else:
+                conv = cls.convert(energy_units, "Hartrees")
             base_freqs *= conv
-            potential = [cls.parse_tensor(f) * conv for f in potential_files]
+            potential = [cls.parse_tensor(f) for f in potential_files]
+            if energy_units is None:
+                if np.max(np.abs(potential[0])) > 1:
+                    conv = cls.convert("Wavenumbers", "Hartrees")
+                else:
+                    conv = 1
+            else:
+                conv = cls.convert(energy_units, "Hartrees")
+            potential = [t * conv for t in potential]
             atoms = cls.parse_atoms(atoms_file)
             coords = cls.parse_coords(coords_file)
             zmat = cls.parse_zmatrix(zmat_file)
             sorting = cls.standard_sorting(zmat)  # we need to re-sort our internal coordinates
+            # raise Exception(sorting)
 
             (freq, matrix, inv), potential_terms = cls.reexpress_normal_modes(
                 (base_freqs, base_mat, base_inv),
@@ -1317,9 +1363,11 @@ class AnneInputHelpers:
 
             # raise Exception(np.diag(potential_terms[0]) * UnitsData.convert("Hartrees", "Wavenumbers"), freq*UnitsData.convert("Hartrees", "Wavenumbers"))
             if return_analyzer:
-                runner = VPTAnalyzer.run_VPT
+                runner = lambda *a, **kw:VPTAnalyzer.run_VPT(*a, calculate_intensities=calculate_intensities, **kw)
+            elif return_runner:
+                runner = VPTRunner.construct
             else:
-                runner = VPTRunner.run_simple
+                runner = lambda *a, **kw:VPTRunner.run_simple(*a, calculate_intensities=calculate_intensities, **kw)
 
             res = runner(
                 [atoms, coords],
@@ -1331,7 +1379,6 @@ class AnneInputHelpers:
                 },
                 potential_terms=potential_terms,
                 internals=zmat,
-                calculate_intensities=calculate_intensities,
                 **opts
             )
             if return_analyzer:
@@ -1357,6 +1404,8 @@ class AnneInputHelpers:
         return {
             "runner":test_runner,
             "freqs":test_freqs,
+            "molecule":test_runner.hamiltonian.molecule,
+            "kinetic":test_runner.hamiltonian.G_terms,
             "potential":test_V,
             "modes":[test_modes, test_inver],
             "states":states,
@@ -1381,4 +1430,26 @@ class AnneInputHelpers:
             calculate_intensities=calculate_intensities
         )
 
+    @classmethod
+    def make_nt_polyad(cls, nt):  #this should be of the form num of quanta give same E
+        results=[]
+        for i in range(len(nt)):
+            for j in range(i+1,len(nt)):
+                a=nt[i]
+                b=nt[j]
+                if b>a:
+                    if b%a==0:
+                        b=b//a
+                        a=1
+                else:
+                    if a%b==0:
+                        a=a//b
+                        b=1
+                baselist=[0]*len(nt)
+                baselist[i]=a
+                twolist=[0]*len(nt)
+                twolist[j]=b
+                results.append([baselist,twolist])
+        return results
+
 VPTRunner.helpers = AnneInputHelpers
\ No newline at end of file
